<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="374"/>
        <source>Cannot generate random number by TPM</source>
        <translation>No es pot generar un nombre aleatori per TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="377"/>
        <source>No available encrypt algorithm.</source>
        <translation>No hi ha cap algorisme d'encriptació disponible.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="380"/>
        <source>TPM encrypt failed.</source>
        <translation>L'encriptació de TPM ha fallat.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="383"/>
        <source>TPM is locked.</source>
        <translation>El TPM està blocat.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="411"/>
        <source>Confirm encrypt %1?</source>
        <translation>Confirmeu l'encriptació de %1?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="414"/>
        <source>The current partition is about to be encrypted and cannot be canceled during the encryption process, please confirm the encryption.</source>
        <translation>La partició actual s'està a punt d'encriptar i no es pot cancel·lar durant el procés. Confirmeu-ho.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="421"/>
        <source>* After encrypting the partition, the system cannot be rolled back to a lower version, please confirm the encryption</source>
        <translation>* Després d'encriptar la partició, el sistema no pot tornar a una versió inferior. Confirmeu-ho.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="432"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="433"/>
        <source>Confirm and Reboot</source>
        <translation>Ho confirmo i reinicia't</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="434"/>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="444"/>
        <source>Decrypt %1?</source>
        <translation>Desencripto %1?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="445"/>
        <source>Decryption can take a long time, so make sure power is connected until the decryption is complete.</source>
        <translation>La desencriptació pot trigar molt de temps, així que assegureu-vos que l'alimentació d'energia estigui connectada fins que s'hagi completat.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::ChgPassphraseDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="18"/>
        <source>passphrase</source>
        <translation>contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="20"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="109"/>
        <source>Recovery key</source>
        <translation>Clau de recuperació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="171"/>
        <source>Validate with %1</source>
        <translation>Valida amb %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="172"/>
        <source>Please input recovery key</source>
        <translation>Introduïu la clau de recuperació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="174"/>
        <source>Old %1</source>
        <translation>Antiga %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="70"/>
        <source>New %1</source>
        <translation>Nova %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="56"/>
        <source>Modify %1</source>
        <translation>Modifica %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="67"/>
        <source>Please enter %1 again</source>
        <translation>Torneu a introduir %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="71"/>
        <source>Repeat %1</source>
        <translation>Repetiu %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="77"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="78"/>
        <source>Confirm</source>
        <translation>Confirma</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="101"/>
        <source>%1 cannot be empty</source>
        <translation>%1 no pot estar buida</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>La clau de recuperació no és vàlida!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="140"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>Com a mínim 8 bits, conté 3 tipus de A-Z, a-z, 0-9 i símbols</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="145"/>
        <source>%1 inconsistency</source>
        <translation>%1 inconsistència</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="177"/>
        <source>Validate with recovery key</source>
        <translation>Valida amb la clau de recuperació</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DecryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>Validate with %1</source>
        <translation>Valida amb %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>passphrase</source>
        <translation>contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="56"/>
        <source>Please input %1 to decrypt device</source>
        <translation>Introduïu % 1 per desencriptar el dispositiu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="103"/>
        <source>Decrypt device</source>
        <translation>Desencripta el dispositiu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="51"/>
        <source>Please input recovery key to decrypt device</source>
        <translation>Introduïu la clau de recuperació per desencriptar el dispositiu.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="57"/>
        <source>Validate with recovery key</source>
        <translation>Valida amb la clau de recuperació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="79"/>
        <source>Passphrase</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="81"/>
        <source>Recovery key</source>
        <translation>Clau de recuperació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="82"/>
        <source>%1 cannot be empty!</source>
        <translation>%1 no pot estar buida</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="87"/>
        <source>Recovery key is not valid!</source>
        <translation>La clau de recuperació no és vàlida!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="111"/>
        <source>Confirm</source>
        <translation>Confirma</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DiskEncryptMenuScene</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="148"/>
        <source>Unlock encrypted partition</source>
        <translation>Desbloca la partició encriptada</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="152"/>
        <source>Cancel partition encryption</source>
        <translation>Cancel·la l'encriptació de la partició</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="156"/>
        <source>passphrase</source>
        <translation>contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="157"/>
        <source>Changing the encryption %1</source>
        <translation>Es canvia l'encriptació: %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="161"/>
        <source>Continue partition encryption</source>
        <translation>Continua l'encriptació de la partició</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="165"/>
        <source>Continue partition decryption</source>
        <translation>Continuar la desencriptació de la partició</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="169"/>
        <source>Enable partition encryption</source>
        <translation>Habilita l'encriptació de particions</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="225"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="226"/>
        <source>Cannot resolve passphrase from TPM</source>
        <translation>No es pot resoldre la contrasenya del TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="248"/>
        <source>PIN error</source>
        <translation>Error de PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="276"/>
        <source>Change passphrase failed</source>
        <translation>No s'ha pogut canviar la contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="525"/>
        <source>Unlock device failed</source>
        <translation>No s'ha pogut desblocar el dispositiu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="526"/>
        <source>Wrong passphrase</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="544"/>
        <source>Mount device failed</source>
        <translation>Ha fallat el muntatge del dispositiu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>unmount</source>
        <translation>desmunta</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>lock</source>
        <translation>bloca</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="588"/>
        <source>Encrypt failed</source>
        <translation>Ha fallat l'encriptació.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="589"/>
        <source>Cannot %1 device %2</source>
        <translation>No es pot %1 el dispositiu %2</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="673"/>
        <source>Reboot to continue encrypt</source>
        <translation>Reinicia per continuar l'encriptació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="674"/>
        <source>Reboot to finish decrypt</source>
        <translation>Reinicia per acabar l'encriptació</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="130"/>
        <source>Unlocked by passphrase</source>
        <translation>Desblocat per contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="157"/>
        <source>In special cases such as forgetting the password or the encryption hardware is damaged, you can decrypt the encrypted partition with the recovery key, please export it to a non-encrypted partition and keep it in a safe place!</source>
        <translation>En casos especials, com ara si oblideu la contrasenya o es danya el maquinari d'encriptació, podeu desencriptar la partició amb la clau de recuperació. Exporteu-la a una partició no encriptada i guardeu-la en un lloc segur!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="172"/>
        <source>Please select a non-encrypted partition as the key file export path.</source>
        <translation>Seleccioneu una partició no encriptada com a camí d'exportació del fitxer de clau.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="192"/>
        <source>Passphrase</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="194"/>
        <source>%1 cannot be empty</source>
        <translation>%1 no pot estar buida</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="225"/>
        <source>%1 inconsistency</source>
        <translation>%1 inconsistència</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="236"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation>El camí d'exportació de la clau de recuperació no pot estar buit!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="241"/>
        <source>Recovery key export path is not exists!</source>
        <translation>El camí d'exportació de la clau de recuperació no existeix!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="248"/>
        <source>Please export to an external device such as a non-encrypted partition or USB flash drive.</source>
        <translation>Exporteu-la a un dispositiu extern, com ara una partició no encriptada o una unitat USB.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="253"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>Aquesta partició és només de lectura. Exporteu-ho a una partició en què es pugui escriure.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="265"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation>La partició està encriptada. Exporteu-la a una partició no encriptada o a un dispositiu extern, com ara una unitat USB.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="421"/>
        <source>TPM is locked and cannot be used for partition encryption. Please cancel the TPM password or choose another unlocking method.</source>
        <translation>El TPM està blocat i no es pot usar per a l'encriptació de particions. Cancel·leu la contrasenya del TPM o trieu un altre mètode de desblocatge.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="423"/>
        <source>TPM error</source>
        <translation>Error de TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="426"/>
        <source>TPM status error!</source>
        <translation>Error de l'estat de TPM!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="316"/>
        <source>Please continue to encrypt partition %1</source>
        <translation>Continueu l'encriptació de la partició %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="321"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="320"/>
        <source>Export Recovery Key</source>
        <translation>Exporta la clau de recuperació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="329"/>
        <source>Set %1</source>
        <translation>Estableix %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="330"/>
        <source>Repeat %1</source>
        <translation>Repetiu %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="336"/>
        <source>passphrase</source>
        <translation>contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="340"/>
        <source>Access to the partition will be unlocked using a passphrase.</source>
        <translation>L'accés a la partició es desblocarà mitjançant una contrasenya.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="347"/>
        <source>Access to the partition will be unlocked using the TPM security chip and PIN.</source>
        <translation>L'accés a la partició es desblocarà mitjançant el xip de seguretat i el PIN TPM.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="350"/>
        <source>Access to the partition will be automatically unlocked using the TPM security chip, no passphrase checking is required.</source>
        <translation>L'accés a la partició es desblocarà automàticament mitjançant el xip de seguretat TPM. No cal comprovar la contrasenya.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="332"/>
        <source>Please enter the %1 again</source>
        <translation>Torneu a introduir %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="110"/>
        <source>Unlock type</source>
        <translation>Tipus de desblocatge</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="131"/>
        <source>Use TPM+PIN to unlock on this computer (recommended)</source>
        <translation>Utilitzeu TPM+PIN per desblocar aquest ordinador (recomanat)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="132"/>
        <source>Automatic unlocking on this computer by TPM</source>
        <translation>Desbloqueig automàtic en aquest ordinador mitjançant TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="220"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>Com a mínim 8 bits, conté 3 tipus de A-Z, a-z, 0-9 i símbols</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Confirm encrypt</source>
        <translation>Confirmeu l'encriptació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="343"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptProgressDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="54"/>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="63"/>
        <source>Re-export the recovery key</source>
        <translation>Torna a exportar la clau de recuperació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="67"/>
        <source>*Recovery key saving failed, please re-save the recovery key to a non-encrypted partition and keep it in a safe place!</source>
        <translation>*No s'ha pogut desar la clau de recuperació. Torneu a desar-la en una partició no encriptada i guardeu-la en un lloc segur.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="82"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="143"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation>El camí d'exportació de la clau de recuperació no pot estar buit!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="148"/>
        <source>Recovery key export path is not exists!</source>
        <translation>El camí d'exportació de la clau de recuperació no existeix!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="154"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>Aquesta partició és només de lectura. Exporteu-ho a una partició en què es pugui escriure.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="167"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation>La partició està encriptada. Exporteu-la a una partició no encriptada o a un dispositiu extern, com ara una unitat USB.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="183"/>
        <source>Cannot create recovery key file!</source>
        <translation>No es pot crear un fitxer de clau de recuperació!</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EventsHandler</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="424"/>
        <source>Preencrypt done</source>
        <translation>Preencriptació feta</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="425"/>
        <source>Device %1 has been preencrypt, please reboot to finish encryption.</source>
        <translation>El dispositiu %1 s'ha preencriptat, reinicieu per acabar-la.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="431"/>
        <source>Preencrypt failed</source>
        <translation>La preencriptació ha fallat.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="432"/>
        <source>Device %1 preencrypt failed, please see log for more information.(%2)</source>
        <translation>Ha fallat la preencriptació del dispositiu %1. Consulteu el registre per obtenir-ne més informació. (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="460"/>
        <source>Wrong passpharse or PIN</source>
        <translation>Contrasenya o PIN incorrecte</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="496"/>
        <source>passphrase</source>
        <translation>contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="499"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="506"/>
        <source>Change %1 done</source>
        <translation>Canvi %1 fet</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="507"/>
        <source>%1's %2 has been changed</source>
        <translation>El %2 de %1 s'ha canviat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="512"/>
        <source>Change %1 failed</source>
        <translation>El canvi %1 ha fallat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="513"/>
        <source>Wrong %1</source>
        <translation>%1 incorrecte</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="518"/>
        <source>Device %1 change %2 failed, please see log for more information.(%3)</source>
        <translation>Ha fallat el canvi % 2 del dispositiu %1, consulteu el registre per obtenir més informació. (% 3)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="180"/>
        <source>Encrypt done</source>
        <translation>Encriptació feta</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="181"/>
        <source>Device %1 has been encrypted</source>
        <translation>El dispositiu %1 s'ha encriptat.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="185"/>
        <source>Encrypt failed</source>
        <translation>Ha fallat l'encriptació.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="186"/>
        <source>Device %1 encrypt failed, please see log for more information.(%2)</source>
        <translation>Ha fallat encriptar el dispositiu %1. Consulteu el registre per obtenir-ne més informació. (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="285"/>
        <source>%1 is under encrypting...</source>
        <translation>%1 s'encripta...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="286"/>
        <source>The encrypting process may have system lag, please minimize the system operation</source>
        <translation>El procés d'encriptació pot tenir un retard de sistema; minimitzeu-ne el funcionament.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="305"/>
        <source>%1 is under decrypting...</source>
        <translation>%1 es desencripta...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="306"/>
        <source>The decrypting process may have system lag, please minimize the system operation</source>
        <translation>El procés de desencriptació pot tenir un retard de sistema; minimitzeu-ne el funcionament.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="452"/>
        <source>Decrypt done</source>
        <translation>Desencriptació feta</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="453"/>
        <source>Device %1 has been decrypted</source>
        <translation>El dispositiu %1 s'ha desencriptat.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="459"/>
        <source>Decrypt disk</source>
        <translation>Desencripta el disc</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="463"/>
        <source>Decrypt failed</source>
        <translation>Ha fallat la desencriptació.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="464"/>
        <source>Device %1 is under encrypting, please decrypt after encryption finished.</source>
        <translation>El dispositiu %1 s'està encriptant. Si us plau, feu la desencriptació un cop hagi acabat.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="469"/>
        <source>Device %1 Decrypt failed, please see log for more information.(%2)</source>
        <translation>Ha fallat desencriptar el dispositiu %1. Consulteu el registre per obtenir-ne més informació. (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="547"/>
        <source>Device is not fully decrypted, please finish decryption before access.</source>
        <translation>El dispositiu no està completament desencriptat, si us plau finalitzeu la desencriptació abans d'accedir-hi.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="554"/>
        <source>Unlocking device failed</source>
        <translation>Ha fallat el desbloqueig del dispositiu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="555"/>
        <source>Please click the right disk menu "Continue partition encryption" to complete partition encryption.</source>
        <translation>Si us plau feu clic a l'opció del menú de dret del disc "Continuar la encriptació de la partició" per completar la encriptació de la partició.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>TPM status is abnormal, please use the recovery key to unlock it</source>
        <translation>L'estat del TPM és anormal, utilitzeu la clau de recuperació per desblocar-lo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="357"/>
        <source>Wrong PIN</source>
        <translation>PIN incorrecte</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="359"/>
        <source>Wrong passphrase</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="361"/>
        <source>TPM error</source>
        <translation>Error de TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="363"/>
        <source>Please use recovery key to unlock device.</source>
        <translation>Utilitzeu la clau de recuperació per desblocar el dispositiu.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::UnlockPartitionDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="52"/>
        <source>Unlock</source>
        <translation>Desbloca</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="81"/>
        <source>Unlock encryption partition</source>
        <translation>Desbloca la partició encriptada</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="85"/>
        <source>Unlock by recovery key</source>
        <translation>Desbloca amb la clau de recuperació</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="90"/>
        <source>Unlock by passphrase</source>
        <translation>Desbloca amb contrasenya</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="91"/>
        <source>Unlock by PIN</source>
        <translation>Desbloca amb PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="93"/>
        <source>Please input recovery key to unlock device</source>
        <translation>Introduïu la clau de recuperació per desblocar el dispositiu.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="99"/>
        <source>Please input passphrase to unlock device</source>
        <translation>Introduïu la contrasenya per desblocar el dispositiu.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="102"/>
        <source>Please input PIN to unlock device</source>
        <translation>Introduïu el PIN per desblocar el dispositiu.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>La clau de recuperació no és vàlida!</translation>
    </message>
</context>
</TS>
